Index: src/heap/gc-tracer.h |
diff --git a/src/heap/gc-tracer.h b/src/heap/gc-tracer.h |
index 33a2ab8cacccb4b4d0e19ef3408f302b63cca330..9a7b28d4fb5624481b1b283c9d5332715d18f323 100644 |
--- a/src/heap/gc-tracer.h |
+++ b/src/heap/gc-tracer.h |
@@ -402,10 +402,10 @@ class GCTracer { |
// Returns 0 if no allocation events have been recorded. |
size_t AllocationThroughputInBytesPerMillisecond(double time_ms) const; |
// Allocation throughput in heap in bytes/milliseconds in |
// the last five seconds. |
// Returns 0 if no allocation events have been recorded. |
- size_t CurrentAllocationThroughputInBytesPerMillisecond() const; |
+ size_t CurrentOldGenerationAllocationThroughputInBytesPerMillisecond() const; |
// Computes the context disposal rate in milliseconds. It takes the time |
// frame of the first recorded context disposal to the current time and |
@@ -402,10 +402,10 @@ class GCTracer { |
// Returns 0 if no allocation events have been recorded. |
size_t AllocationThroughputInBytesPerMillisecond(double time_ms) const; |
- // Allocation throughput in heap in bytes/milliseconds in |
+ // Allocation throughput in old generation in bytes/milliseconds in |
// the last five seconds. |
// Returns 0 if no allocation events have been recorded. |